/**
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * @format
 */
import BaseDevice from './devices/BaseDevice';
import { Logger, FlipperServer } from 'flipper-common';
import EventEmitter from 'eventemitter3';
import { ClientQuery, ClientResponseType, ClientErrorType } from 'flipper-common';
import { _SandyPluginInstance, _SandyPluginDefinition } from 'flipper-plugin-core';
type Plugins = Set<string>;
type PluginsArr = Array<string>;
export type Params = {
    api: string;
    method: string;
    params?: Object;
};
export type RequestMetadata = {
    method: string;
    id: number;
    params: Params | undefined;
};
export interface ClientConnection {
    send(data: any): void;
    sendExpectResponse(data: any): Promise<ClientResponseType>;
}
export default abstract class AbstractClient extends EventEmitter {
    connected: import("flipper-plugin-core").Atom<boolean>;
    id: string;
    query: ClientQuery;
    sdkVersion: number;
    messageIdCounter: number;
    plugins: Plugins;
    backgroundPlugins: Plugins;
    connection: ClientConnection | null | undefined;
    activePlugins: Set<string>;
    device: BaseDevice;
    logger: Logger;
    sandyPluginStates: Map<string, _SandyPluginInstance>;
    private readonly serverAddOnControls;
    private readonly flipperServer;
    private resolveInitPromise;
    readonly initializationPromise: Promise<unknown>;
    constructor(id: string, query: ClientQuery, conn: ClientConnection | null | undefined, logger: Logger, plugins: Plugins | null | undefined, device: BaseDevice, flipperServer: FlipperServer);
    isBackgroundPlugin(pluginId: string): boolean;
    protected abstract shouldConnectAsBackgroundPlugin(pluginId: string): boolean;
    init(): Promise<void>;
    protected loadPlugins(_phase: 'init' | 'refresh'): Promise<Plugins>;
    protected loadPlugin(plugin: _SandyPluginDefinition, initialState?: Record<string, any>): void;
    startPluginIfNeeded(plugin: _SandyPluginDefinition | undefined): void;
    stopPluginIfNeeded(pluginId: string, _force?: boolean): void;
    disconnect(): void;
    destroy(): void;
    protected abstract getPlugin(pluginId: string): Promise<_SandyPluginDefinition | undefined>;
    protected getBackgroundPlugins(): Promise<PluginsArr>;
    refreshPlugins(): Promise<void>;
    onMessage(msg: string): void;
    protected handleExecuteMessage(params: Params): boolean;
    protected onResponse(data: ClientResponseType, resolve: ((a: any) => any) | undefined, reject: (error: ClientErrorType) => any): void;
    protected rawCall<T>(method: string, fromPlugin: boolean, params?: Params): Promise<T>;
    protected isAcceptingMessagesFromPlugin(plugin: string | null | undefined): boolean | null | undefined;
    protected getPerformanceMark(data: RequestMetadata): string;
    protected getLogEventName(data: RequestMetadata): string;
    initPlugin(pluginId: string): void;
    deinitPlugin(pluginId: string): void;
    protected rawSend(method: string, params?: Object): void;
    call(api: string, method: string, fromPlugin: boolean, params?: Object): Promise<Object>;
    send(api: string, method: string, params?: Object): void;
    supportsMethod(api: string, method: string): Promise<boolean>;
}
export {};
//# sourceMappingURL=AbstractClient.d.ts.map