"use strict";
/**
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * @format
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const BaseDevice_1 = __importDefault(require("./BaseDevice"));
class ArchivedDevice extends BaseDevice_1.default {
    constructor(options) {
        var _a;
        super({
            async connect() { },
            close() { },
            exec(command, ..._args) {
                throw new Error(`[Archived device] Cannot invoke command ${command} on an archived device`);
            },
            on(event) {
                console.warn(`Cannot subscribe to server events from an Archived device: ${event}`);
            },
            off() { },
        }, {
            deviceType: options.deviceType,
            title: options.title,
            os: options.os,
            serial: options.serial,
            icon: 'box',
            features: {
                screenCaptureAvailable: false,
                screenshotAvailable: false,
            },
        });
        this.isArchived = true;
        this.connected.set(false);
        this.source = options.source || '';
        this.supportRequestDetails = options.supportRequestDetails;
        this.archivedScreenshotHandle = (_a = options.screenshotHandle) !== null && _a !== void 0 ? _a : null;
    }
    displayTitle() {
        return `${this.title} ${this.source ? '(Imported)' : '(Offline)'}`;
    }
    getArchivedScreenshotHandle() {
        return this.archivedScreenshotHandle;
    }
    /**
     * @override
     */
    async startLogging() {
        // No-op
    }
    /**
     * @override
     */
    async stopLogging() {
        // No-op
    }
}
exports.default = ArchivedDevice;
//# sourceMappingURL=ArchivedDevice.js.map