/**
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * @format
 */
import { Device, _SandyDevicePluginInstance, _SandyPluginDefinition, DeviceLogListener, Idler, CrashLogListener } from 'flipper-plugin-core';
import { DeviceLogEntry, DeviceOS, DeviceType, DeviceDescription, FlipperServer, CrashLog } from 'flipper-common';
import { DeviceSpec, PluginDetails } from 'flipper-common';
type PluginDefinition = _SandyPluginDefinition;
type PluginMap = Map<string, PluginDefinition>;
export type DeviceExport = {
    os: DeviceOS;
    title: string;
    deviceType: DeviceType;
    serial: string;
    pluginStates: Record<string, any>;
};
export default class BaseDevice implements Device {
    private pluginErrorHandler?;
    description: DeviceDescription;
    flipperServer: FlipperServer;
    isArchived: boolean;
    hasDevicePlugins: boolean;
    private readonly serverAddOnControls;
    constructor(flipperServer: FlipperServer, description: DeviceDescription, pluginErrorHandler?: ((msg: string) => void) | undefined);
    get isConnected(): boolean;
    get os(): import("flipper-common").OS;
    get title(): string;
    get deviceType(): DeviceType;
    get serial(): string;
    get specs(): DeviceSpec[];
    get icon(): string | undefined;
    logListeners: Map<Symbol, DeviceLogListener>;
    crashListeners: Map<Symbol, CrashLogListener>;
    readonly connected: import("flipper-plugin-core").Atom<boolean>;
    source: string;
    sandyPluginStates: Map<string, _SandyDevicePluginInstance>;
    supportsOS(os: DeviceOS): boolean;
    displayTitle(): string;
    exportState(idler: Idler, onStatusMessage: (msg: string) => void, selectedPlugins: string[]): Promise<Record<string, any>>;
    toJSON(): {
        os: import("flipper-common").OS;
        title: string;
        deviceType: DeviceType;
        serial: string;
    };
    private deviceLogEventHandler;
    addLogEntry(entry: DeviceLogEntry): void;
    startLogging(): Promise<void>;
    stopLogging(): void;
    addLogListener(callback: DeviceLogListener): Symbol;
    removeLogListener(id: Symbol): void;
    private crashLogEventHandler;
    addCrashEntry(entry: CrashLog): void;
    startCrashWatcher(): Promise<void>;
    stopCrashWatcher(): void;
    addCrashListener(callback: CrashLogListener): Symbol;
    removeCrashListener(id: Symbol): void;
    navigateToLocation(location: string): Promise<void>;
    installApp(appBundlePath: string, timeout?: number): Promise<void>;
    screenshot(): Promise<Uint8Array | undefined>;
    startScreenCapture(destination: string): Promise<void>;
    stopScreenCapture(): Promise<string | null>;
    executeShell(command: string): Promise<string>;
    sendMetroCommand(command: string): Promise<void>;
    forwardPort(local: string, remote: string): Promise<boolean>;
    clearLogs(): Promise<void>;
    supportsPlugin(plugin: PluginDefinition | PluginDetails): any;
    loadDevicePlugins(devicePlugins: PluginMap, enabledDevicePlugins: Set<string>, pluginStates?: Record<string, any>): void;
    loadDevicePlugin(plugin: PluginDefinition, initialState?: any): void;
    unloadDevicePlugin(pluginId: string): void;
    disconnect(): void;
    destroy(): void;
}
export {};
//# sourceMappingURL=BaseDevice.d.ts.map