"use strict";
/**
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * @format
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.downloadFileFactory = void 0;
const flipper_common_1 = require("flipper-common");
const downloadFileFactory = (renderHost) => async (url, dest, { onProgressUpdate, ...options } = {}) => {
    const downloadDescriptor = (await renderHost.flipperServer.exec('download-file-start', url, dest, options));
    let onProgressUpdateWrapped;
    const completed = new Promise((resolve, reject) => {
        onProgressUpdateWrapped = (progressUpdate) => {
            if (progressUpdate.id === downloadDescriptor.id) {
                const { status } = progressUpdate;
                switch (status) {
                    case 'downloading': {
                        onProgressUpdate === null || onProgressUpdate === void 0 ? void 0 : onProgressUpdate(progressUpdate);
                        break;
                    }
                    case 'success': {
                        resolve(progressUpdate.downloaded);
                        break;
                    }
                    case 'error': {
                        reject(new Error(`File download failed. Last message: ${JSON.stringify(progressUpdate)}`));
                        break;
                    }
                    default: {
                        (0, flipper_common_1.assertNever)(status);
                    }
                }
            }
        };
        renderHost.flipperServer.on('download-file-update', onProgressUpdateWrapped);
    });
    // eslint-disable-next-line promise/catch-or-return
    completed.finally(() => {
        renderHost.flipperServer.off('download-file-update', onProgressUpdateWrapped);
    });
    downloadDescriptor.completed = completed;
    return downloadDescriptor;
};
exports.downloadFileFactory = downloadFileFactory;
//# sourceMappingURL=downloadFile.js.map