"use strict";
/**
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * @format
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.baseFlipperLibImplementation = void 0;
const flipper_common_1 = require("flipper-common");
const constants_1 = __importDefault(require("../fb-stubs/constants"));
const downloadFile_1 = require("./downloadFile");
const js_base64_1 = require("js-base64");
function baseFlipperLibImplementation(renderHost, logger) {
    return {
        isFB: !constants_1.default.IS_PUBLIC_BUILD,
        logger,
        GK: renderHost.GK,
        writeTextToClipboard: renderHost.writeTextToClipboard,
        openLink: renderHost.openLink,
        importFile: renderHost.importFile,
        exportFile: renderHost.exportFile,
        exportFileBinary: renderHost.exportFileBinary,
        paths: {
            appPath: renderHost.serverConfig.paths.appPath,
            homePath: renderHost.serverConfig.paths.homePath,
            staticPath: renderHost.serverConfig.paths.staticPath,
            tempPath: renderHost.serverConfig.paths.tempPath,
        },
        environmentInfo: {
            os: renderHost.serverConfig.environmentInfo.os,
            env: renderHost.serverConfig.env,
            isHeadlessBuild: renderHost.serverConfig.environmentInfo.isHeadlessBuild,
        },
        intern: {
            graphGet: (...args) => renderHost.flipperServer.exec('intern-graph-get', ...args),
            graphPost: (...args) => renderHost.flipperServer.exec('intern-graph-post', ...args),
            isLoggedIn: () => renderHost.flipperServer.exec('is-logged-in'),
        },
        remoteServerContext: {
            childProcess: {
                exec: async (command, options) => renderHost.flipperServer.exec('node-api-exec', command, options),
            },
            fs: {
                access: async (path, mode) => renderHost.flipperServer.exec('node-api-fs-access', path, mode),
                pathExists: async (path, mode) => renderHost.flipperServer.exec('node-api-fs-pathExists', path, mode),
                unlink: async (path) => renderHost.flipperServer.exec('node-api-fs-unlink', path),
                mkdir: (async (path, options) => renderHost.flipperServer.exec('node-api-fs-mkdir', path, options)),
                rm: async (path, options) => renderHost.flipperServer.exec('node-api-fs-rm', path, options),
                copyFile: async (src, dest, flags) => renderHost.flipperServer.exec('node-api-fs-copyFile', src, dest, flags),
                constants: flipper_common_1.fsConstants,
                stat: async (path) => renderHost.flipperServer.exec('node-api-fs-stat', path),
                readlink: async (path) => renderHost.flipperServer.exec('node-api-fs-readlink', path),
                readFile: (path, options) => renderHost.flipperServer.exec('node-api-fs-readfile', path, options),
                readFileBinary: async (path) => js_base64_1.Base64.toUint8Array(await renderHost.flipperServer.exec('node-api-fs-readfile-binary', path)),
                writeFile: (path, contents, options) => renderHost.flipperServer.exec('node-api-fs-writefile', path, contents, options),
                writeFileBinary: async (path, contents) => {
                    const base64contents = js_base64_1.Base64.fromUint8Array(contents);
                    return await renderHost.flipperServer.exec('node-api-fs-writefile-binary', path, base64contents);
                },
            },
            downloadFile: (0, downloadFile_1.downloadFileFactory)(renderHost),
        },
    };
}
exports.baseFlipperLibImplementation = baseFlipperLibImplementation;
//# sourceMappingURL=index.js.map