"use strict";
/**
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * @format
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.createServerAddOnControls = void 0;
const flipper_common_1 = require("flipper-common");
const createServerAddOnControls = (flipperServer) => {
    const methodHandlers = new Map();
    const catchAllHandlers = new Map();
    let subscribed = false;
    const subscriptionCb = ({ params }) => {
        var _a;
        const pluginName = params.api;
        const methodHandler = (_a = methodHandlers.get(pluginName)) === null || _a === void 0 ? void 0 : _a.get(params.method);
        if (methodHandler) {
            methodHandler(params.params);
            return;
        }
        const catchAllHandler = catchAllHandlers.get(pluginName);
        catchAllHandler === null || catchAllHandler === void 0 ? void 0 : catchAllHandler(params.method, params.params);
    };
    return {
        start: (pluginName, details, owner) => flipperServer.exec('plugins-server-add-on-start', pluginName, details, owner),
        stop: (pluginName, owner) => flipperServer.exec('plugins-server-add-on-stop', pluginName, owner),
        sendMessage: async (pluginName, method, params) => {
            const res = await flipperServer.exec('plugins-server-add-on-request-response', {
                method: 'execute',
                params: {
                    method,
                    api: pluginName,
                    params,
                },
            });
            if (res.error) {
                throw (0, flipper_common_1.deserializeRemoteError)(res.error);
            }
            return res.success;
        },
        receiveMessage: (pluginName, method, receiver) => {
            if (!methodHandlers.has(pluginName)) {
                methodHandlers.set(pluginName, new Map());
            }
            methodHandlers.get(pluginName).set(method, receiver);
            // Subscribe client/device to messages from flipper server only when the first plugin subscribes to them
            if (!subscribed) {
                subscribed = true;
                flipperServer.on('plugins-server-add-on-message', subscriptionCb);
            }
        },
        receiveAnyMessage: (pluginName, receiver) => {
            catchAllHandlers.set(pluginName, receiver);
        },
        unsubscribePlugin: (pluginName) => {
            methodHandlers.delete(pluginName);
            catchAllHandlers.delete(pluginName);
        },
        unsubscribe: () => {
            flipperServer.off('plugins-server-add-on-message', subscriptionCb);
        },
    };
};
exports.createServerAddOnControls = createServerAddOnControls;
//# sourceMappingURL=createServerAddOnControls.js.map